Class: MailinatorClient::Messages

Inherits:
Object
  • Object
show all
Defined in:
lib/mailinator_client/messages.rb

Overview

Class containing all the actions for the Messages Resource

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Messages

Returns a new instance of Messages.



30
31
32
# File 'lib/mailinator_client/messages.rb', line 30

def initialize(client)
  @client = client
end

Instance Method Details

#delete_all_domain_messages(params = {}) ⇒ Object

Deletes ALL messages from a Private Domain. Caution: This action is irreversible.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

Responses:

Raises:

  • (ArgumentError)


253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/mailinator_client/messages.rb', line 253

def delete_all_domain_messages(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)

  path = "/domains/#{params[:domain]}/inboxes"

  @client.request(
    method: :delete,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

#delete_all_inbox_messages(params = {}) ⇒ Object

Deletes ALL messages from a specific private inbox.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

  • string inbox - The Inbox name

Responses:

Raises:

  • (ArgumentError)


283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/mailinator_client/messages.rb', line 283

def delete_all_inbox_messages(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}"

  @client.request(
    method: :delete,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

#delete_message(params = {}) ⇒ Object

Deletes a specific messages.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

  • string inbox - The Inbox name

  • string messageId - The Message id

Responses:

Raises:

  • (ArgumentError)


315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/mailinator_client/messages.rb', line 315

def delete_message(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)
  raise ArgumentError.new("message id is required") unless params.has_key?(:messageId)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}/messages/#{params[:messageId]}"

  @client.request(
    method: :delete,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

#fetch_attachment(params = {}) ⇒ Object

Retrieves a specific attachment.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

  • string inbox - The Inbox name

  • string messageId - The Message id

  • string attachmentId - The Attachment id

Responses:

Raises:

  • (ArgumentError)


188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/mailinator_client/messages.rb', line 188

def fetch_attachment(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)
  raise ArgumentError.new("message id is required") unless params.has_key?(:messageId)
  raise ArgumentError.new("attachment id is required") unless params.has_key?(:attachmentId)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}/messages/#{params[:messageId]}/attachments/#{params[:attachmentId]}"

  @client.request(
    method: :get,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

#fetch_attachments(params = {}) ⇒ Object

Retrieves a list of attachments for a message. Note attachments are expected to be in Email format.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

  • string inbox - The Inbox name

  • string messageId - The Message id

Responses:

Raises:

  • (ArgumentError)


153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/mailinator_client/messages.rb', line 153

def fetch_attachments(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)
  raise ArgumentError.new("message id is required") unless params.has_key?(:messageId)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}/messages/#{params[:messageId]}/attachments"

  @client.request(
    method: :get,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

#fetch_inbox(params = {}) ⇒ Object

Retrieves a list of messages summaries. You can retreive a list by inbox, inboxes, or entire domain.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

  • string inbox - The Inbox name

  • number skip - Skip this many emails in your Private Domain

  • number limit - Number of emails to fetch from your Private Domain

  • string sort - Sort results by ascending or descending

  • boolean decodeSubject - true: decode encoded subjects

Responses:

Raises:

  • (ArgumentError)


50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/mailinator_client/messages.rb', line 50

def fetch_inbox(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { skip: 0, limit: 50, sort: "ascending", decodeSubject: false }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)

  query_params[:skip] = params[:skip] if params.has_key?(:skip)
  query_params[:limit] = params[:limit] if params.has_key?(:limit)
  query_params[:sort] = params[:sort] if params.has_key?(:sort)
  query_params[:decodeSubject] = params[:decodeSubject] if params.has_key?(:decodeSubject)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}"

  @client.request(
    method: :get,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

#fetch_message(params = {}) ⇒ Object

Retrieves a specific message by id.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

  • string inbox - The Inbox name

  • string messageId - The Message id

Responses:

Raises:

  • (ArgumentError)


87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/mailinator_client/messages.rb', line 87

def fetch_message(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)
  raise ArgumentError.new("message id is required") unless params.has_key?(:messageId)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}/messages/#{params[:messageId]}"

  @client.request(
    method: :get,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

Retrieves all links found within a given email.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

  • string inbox - The Inbox name

  • string messageId - The Message id

Responses:

Raises:

  • (ArgumentError)


222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/mailinator_client/messages.rb', line 222

def fetch_message_links(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)
  raise ArgumentError.new("message id is required") unless params.has_key?(:messageId)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}/messages/#{params[:messageId]}/links"

  @client.request(
    method: :get,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

#fetch_sms_message(params = {}) ⇒ Object

Retrieves a specific SMS message by sms number.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

  • string domainId - The Domain name or the Domain id

  • string inbox - The Inbox name

  • string teamSmsNumber - The Team sms number

Responses:

Raises:

  • (ArgumentError)


120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/mailinator_client/messages.rb', line 120

def fetch_sms_message(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)
  raise ArgumentError.new("team sms number is required") unless params.has_key?(:teamSmsNumber)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}/#{params[:teamSmsNumber]}"

  @client.request(
    method: :get,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end

#inject_message(params = {}) ⇒ Object

Deliver a JSON message into your private domain.

Authentication: The client must be configured with a valid api access token to call this action.

Parameters:

Responses:

Raises:

  • (ArgumentError)


348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/mailinator_client/messages.rb', line 348

def inject_message(params = {})
  params = Utils.symbolize_hash_keys(params)
  query_params = { }
  headers = {}
  body = nil

  raise ArgumentError.new("domain is required") unless params.has_key?(:domain)
  raise ArgumentError.new("inbox is required") unless params.has_key?(:inbox)
  raise ArgumentError.new("messageToPost is required") unless params.has_key?(:messageToPost)

  body = params[:messageToPost] if params.has_key?(:messageToPost)

  path = "/domains/#{params[:domain]}/inboxes/#{params[:inbox]}/messages"

  @client.request(
    method: :post,
    path: path,
    query: query_params,
    headers: headers,
    body: body)
end